aboutsummaryrefslogtreecommitdiffstats
path: root/src/0x.ts
diff options
context:
space:
mode:
Diffstat (limited to 'src/0x.ts')
-rw-r--r--src/0x.ts5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/0x.ts b/src/0x.ts
index d7a01ba70..6dfd1a8f5 100644
--- a/src/0x.ts
+++ b/src/0x.ts
@@ -199,8 +199,9 @@ export class ZeroEx {
let msgHashHex;
const nodeVersion = await this._web3Wrapper.getNodeVersionAsync();
const isParityNode = utils.isParityNode(nodeVersion);
- if (isParityNode) {
- // Parity node adds the personalMessage prefix itself
+ const isTestRpc = utils.isTestRpc(nodeVersion);
+ if (isParityNode || isTestRpc) {
+ // Parity and TestRpc nodes add the personalMessage prefix itself
msgHashHex = orderHash;
} else {
const orderHashBuff = ethUtil.toBuffer(orderHash);